==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/admin/messages/el/base.php <==
<?php

return [
    '<strong>Administration</strong> menu' => 'Μενού <strong>Διαχείριση</strong>',
    '<strong>Maintenance</strong> Mode' => 'Λειτουργία <strong>Συντήρηση</strong>',
    '<strong>Warning</strong> incomplete setup!' => '<strong>Προειδοποίηση<strong> Ελλιπής εγκατάσταση!</strong></strong>',
    'About' => 'Σχετικά',
    'Admin' => 'Διαχειριστής',
    'Administration' => 'Διαχείριση',
    'Administrative group' => 'Διαχειριστική ομάδα',
    'Administrators' => 'Διαχειριστές',
    'Advanced' => 'Προηγμένη',
    'Advanced settings' => 'Προηγμένες ρυθμίσεις',
    'Appearance' => 'Εμφάνιση',
    'Approval' => 'Έγκριση',
    'Authentication' => 'Αυθεντικοποίηση',
    'Back to overview' => 'Επιστροφή στην επισκόπηση',
    'Back to user overview' => 'Επιστροφή στην επισκόπηση χρήστη',
    'Base URL needs to begin with http:// or https://' => 'Η βασική διεύθυνση URL πρέπει να ξεκινά με  http:// ή https://',
    'Basic' => 'Βασικό',
    'Caching' => 'Προσωρινή αποθήκευση',
    'Configure' => 'Ρύθμιση',
    'Cronjobs' => 'Χρονοπρογρ/στής εργασιών',
    'Deactivate' => 'Απενεργοποίηση',
    'Default' => 'Προκαθορισμένο',
    'Default group for administrators of this HumHub Installation' => 'Προεπιλεγμένη ομάδα για διαχειριστές αυτής της εγκατάστασης HumHub',
    'Default group for all newly registered users of the network' => 'Προεπιλεγμένη ομάδα για όλους τους νέους εγγεγραμμένους χρήστες του δικτύου',
    'Delete all' => 'Διαγραφή Όλων',
    'Delete selected rows' => 'Διαγραφή επιλεγμένων σειρών',
    'Design' => 'Σχέδιο',
    'Files' => 'Αρχεία',
    'General' => 'Γενικά',
    'Groups' => 'Ομάδες',
    'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => 'Ομάδες (Σημείωση: Η ομάδα διαχειριστών αυτού του χρήστη δεν μπορεί να διαχειριστεί με τα δικαιώματά σας)',
    'Information' => 'Πληροφορίες',
    'Invalid user state: {state}' => 'Μη έγκυρη κατάσταση χρήστη: {state}',
    'Invited by' => 'Προσκλήθηκε από τον/την',
    'Logging' => 'Καταγραφή',
    'Logs' => 'Αρχεία καταγραφής',
    'Mailing' => 'Ταχυδρομικός',
    'Modules' => 'Ενότητες',
    'No modules installed yet. Install some to enhance the functionality!' => 'Δεν έχουν εγκατασταθεί ακόμα μονάδες. Εγκαταστήστε μερικές για να βελτιώσετε τη λειτουργικότητα!',
    'Notifications' => 'Ενημερώσεις',
    'OEmbed' => 'Ενσωματωμένο περιεχόμενο',
    'OEmbed providers' => 'Ενσωμάτωση περιεχομένου πάροχων',
    'Open documentation' => 'Άνοιγμα τεκμηρίωσης',
    'Pending user registrations' => 'Αναμονή εγγραφής χρήστη',
    'People' => 'Ανθρωποι',
    'Permissions' => 'Δικαιώματα',
    'Proxy' => 'Πληρεξούσιο',
    'Search' => 'Αναζήτηση',
    'Self test' => 'Τεστ αυτοαξιολόγησης',
    'Set as default' => 'Ορισμός ως προεπιλογή',
    'Settings' => 'Ρυθμίσεις',
    'Sign up' => 'Εγγραφή',
    'Spaces' => 'Χώροι',
    'Statistics' => 'Στατιστικά',
    'The cron job for the background jobs (queue) does not seem to work properly.' => 'Ο Χρονοπρογρ/στής για τις εργασίες υπόβαθρου (στη σειρά) δεν φαίνεται να λειτουργεί σωστά.',
    'The cron job for the regular tasks (cron) does not seem to work properly.' => 'Ο Χρονοπρογρ/στής εργασίας για τις τακτικές εργασίες (cron) δεν φαίνεται να λειτουργεί σωστά.',
    'Uninstall' => 'Απεγκατάσταση',
    'User not found!' => 'Ο χρήστης δεν βρέθηκε!',
    'Userprofiles' => 'Προφίλ χρήστη',
    'Users' => 'Χρήστες',
    '<strong>Module</strong> Administration' => '',
    'Activate' => '',
    'Add Licence Key' => '',
    'Invite by email' => '',
    'Invite by link' => '',
    'Search...' => '',
];

==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/admin/messages/el/base.php <==
<?php

return [
    '<strong>Administration</strong> menu' => 'Μενού <strong>Διαχείριση</strong>',
    '<strong>Maintenance</strong> Mode' => 'Λειτουργία <strong>Συντήρηση</strong>',
    '<strong>Warning</strong> incomplete setup!' => '<strong>Προειδοποίηση<strong> Ελλιπής εγκατάσταση!</strong></strong>',
    'About' => 'Σχετικά',
    'Admin' => 'Διαχειριστής',
    'Administration' => 'Διαχείριση',
    'Administrative group' => 'Διαχειριστική ομάδα',
    'Administrators' => 'Διαχειριστές',
    'Advanced' => 'Προηγμένη',
    'Advanced settings' => 'Προηγμένες ρυθμίσεις',
    'Appearance' => 'Εμφάνιση',
    'Approval' => 'Έγκριση',
    'Authentication' => 'Αυθεντικοποίηση',
    'Back to overview' => 'Επιστροφή στην επισκόπηση',
    'Back to user overview' => 'Επιστροφή στην επισκόπηση χρήστη',
    'Base URL needs to begin with http:// or https://' => 'Η βασική διεύθυνση URL πρέπει να ξεκινά με  http:// ή https://',
    'Basic' => 'Βασικό',
    'Caching' => 'Προσωρινή αποθήκευση',
    'Configure' => 'Ρύθμιση',
    'Cronjobs' => 'Χρονοπρογρ/στής εργασιών',
    'Deactivate' => 'Απενεργοποίηση',
    'Default' => 'Προκαθορισμένο',
    'Default group for administrators of this HumHub Installation' => 'Προεπιλεγμένη ομάδα για διαχειριστές αυτής της εγκατάστασης HumHub',
    'Default group for all newly registered users of the network' => 'Προεπιλεγμένη ομάδα για όλους τους νέους εγγεγραμμένους χρήστες του δικτύου',
    'Delete all' => 'Διαγραφή Όλων',
    'Delete selected rows' => 'Διαγραφή επιλεγμένων σειρών',
    'Design' => 'Σχέδιο',
    'Enable module...' => 'Ενεργοποίηση μονάδας...',
    'Files' => 'Αρχεία',
    'General' => 'Γενικά',
    'Groups' => 'Ομάδες',
    'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => 'Ομάδες (Σημείωση: Η ομάδα διαχειριστών αυτού του χρήστη δεν μπορεί να διαχειριστεί με τα δικαιώματά σας)',
    'Information' => 'Πληροφορίες',
    'Invalid user state: {state}' => 'Μη έγκυρη κατάσταση χρήστη: {state}',
    'Invited by' => 'Προσκλήθηκε από τον/την',
    'Logging' => 'Καταγραφή',
    'Logs' => 'Αρχεία καταγραφής',
    'Mailing' => 'Ταχυδρομικός',
    'Modules' => 'Ενότητες',
    'No modules installed yet. Install some to enhance the functionality!' => 'Δεν έχουν εγκατασταθεί ακόμα μονάδες. Εγκαταστήστε μερικές για να βελτιώσετε τη λειτουργικότητα!',
    'Notifications' => 'Ενημερώσεις',
    'OEmbed' => 'Ενσωματωμένο περιεχόμενο',
    'OEmbed providers' => 'Ενσωμάτωση περιεχομένου πάροχων',
    'Open documentation' => 'Άνοιγμα τεκμηρίωσης',
    'Pending user registrations' => 'Αναμονή εγγραφής χρήστη',
    'People' => 'Ανθρωποι',
    'Permissions' => 'Δικαιώματα',
    'Proxy' => 'Πληρεξούσιο',
    'Self test' => 'Τεστ αυτοαξιολόγησης',
    'Set as default' => 'Ορισμός ως προεπιλογή',
    'Settings' => 'Ρυθμίσεις',
    'Sign up' => 'Εγγραφή',
    'Spaces' => 'Χώροι',
    'Statistics' => 'Στατιστικά',
    'The cron job for the background jobs (queue) does not seem to work properly.' => 'Ο Χρονοπρογρ/στής για τις εργασίες υπόβαθρου (στη σειρά) δεν φαίνεται να λειτουργεί σωστά.',
    'The cron job for the regular tasks (cron) does not seem to work properly.' => 'Ο Χρονοπρογρ/στής εργασίας για τις τακτικές εργασίες (cron) δεν φαίνεται να λειτουργεί σωστά.',
    'Uninstall' => 'Απεγκατάσταση',
    'User not found!' => 'Ο χρήστης δεν βρέθηκε!',
    'Userprofiles' => 'Προφίλ χρήστη',
    'Users' => 'Χρήστες',
    '<strong>Module</strong> administration' => '',
    'Activate' => '',
    'Active Modules' => '',
    'Add more modules' => '',
    'Inactive Modules' => '',
    'Install Updates' => '',
    'Invite by email' => '',
    'Invite by link' => '',
    'Keep your system up-to-date and benefit from the latest improvements.' => '',
    'Show in Marketplace' => '',
    'This overview shows you all installed modules and allows you to enable, disable, configure and of course uninstall them. To discover new modules, take a look into our Marketplace. Please note that deactivating or uninstalling a module will result in the loss of any content that was created with that module.' => '',
    'Updates available for {count} of your modules' => '',
    'Version' => '',
    'Visit Marketplace' => '',
    'You do not have the permission to configure modules. Please contact the administrator for further information.' => '',
    'You do not have the permission to manage modules. Please contact the administrator for further information.' => '',
];
